@@ -134,7 +134,7 @@ class Curve:
     def getIvFromStrike(self, strike):
         assert strike > 0
         lowestIv = lowestStrike = highestIv = highestStrike = 0
-        for idx in range(len(self.str)):
+        for idx in range(len(self.strikes)):
             if strike < self.strikes[idx]:
                 lowestIv = self.markIvs[idx]
                 lowestStrike = self.strikes[idx]
